@@ -22,29 +22,42 @@
 
 #include "chinesecalendar.h"
 
+Cnote *note = 0;
+
 ChineseCalendar::ChineseCalendar(QWidget *parent)
     : QWidget(parent)
 {
     setupUi(this);
 
+    note = new Cnote;
+    QDesktopWidget desktop;
+    int width = desktop.screenGeometry().width();
+    int height = desktop.screenGeometry().height();
+    note->setGeometry(QRect(width-400,80,224,280));
+    note->hide();
+
     bg = new QPixmap(":/img/chinesecalendarBGyellow.png");
-    icon = QIcon(":/img/chinesecalendar.png");
+    icon = QIcon(":/img/icon.png");
+    icon64 = QIcon(":/img/chinesecalendar-64.png");
     mycalendat=new CCBO;
     mycalendat->InitConnection(QDir::currentPath ());
     selectedDate = QDate::currentDate();
 	monthCombo->setCurrentIndex(selectedDate.month() - 1);
-    YearSelect->setDate(selectedDate);
+    YearSelect->setCurrentIndex(selectedDate.year()-1900);
     connect(monthCombo, SIGNAL(currentIndexChanged(int)), this, SLOT(setMonth(int)));
     connect(monthCombo, SIGNAL(activated(int)), this, SLOT(setMonth(int)));
-    connect(YearSelect, SIGNAL(dateChanged(QDate)), this, SLOT(setYear(QDate)));
+    connect(YearSelect, SIGNAL(currentIndexChanged(int)), this, SLOT(setYear(int)));
     connect(this->backtotoday, SIGNAL(clicked()), this, SLOT(backtoday()));
+    connect(note,SIGNAL(save(QString)),this,SLOT(savedata(QString)));
+
+
 
     this->TbnextMonth->setStyleSheet("QPushButton{background-color:transparent;color:rgb(200,200,150);}QPushButton:hover{color:rgb(255,255,255);}");
     this->TbnextYear->setStyleSheet("QPushButton{background-color:transparent;color:rgb(200,200,150);}QPushButton:hover{color:rgb(255,255,255);}");
     this->TbpreviousMonth->setStyleSheet("QPushButton{background-color:transparent;color:rgb(200,200,150);}QPushButton:hover{color:rgb(255,255,255);}");
     this->TbpreviousYear->setStyleSheet("QPushButton{background-color:transparent;color:rgb(200,200,150);}QPushButton:hover{color:rgb(255,255,255);}");
     this->backtotoday->setStyleSheet("QPushButton{background-color:transparent;color:rgb(200,200,150);}QPushButton:hover{color:rgb(255,255,255);}");
-    this->YearSelect->setStyleSheet("QDateEdit{border: 2px solid lightgray;border-radius: 5px;}");
+    this->YearSelect->setStyleSheet("QComboBox{border: 2px solid lightgray;border-radius: 5px;font:12pt;}");
     this->monthCombo->setStyleSheet("QComboBox{border: 2px solid lightgray;border-radius: 5px;font:12pt;}");
     this->label->setStyleSheet("QLabel{font:12pt;}");
     this->label_2->setStyleSheet("QLabel{font:12pt;}");
@@ -81,6 +94,11 @@ ChineseCalendar::ChineseCalendar(QWidget *parent)
     QString chineseday = QString("农历 %1%2").arg(chinesemonth).arg(datebase.cday);
     QString chineseyear = QString("%1年(%2年)").arg(datebase.ganzhi).arg(datebase.shengxiao);
 
+    QString chineseyi = QString("%1").arg(datebase.yi);
+    QStringList chineseyilist = chineseyi.split("、");
+    QString chineseji = QString("%2").arg(datebase.ji);
+    QStringList chinesejilist = chineseji.split("、");
+
     QFont font;
     QPalette pa;
     font.setPointSize(48);
@@ -98,7 +116,53 @@ ChineseCalendar::ChineseCalendar(QWidget *parent)
     this->label_14->setText(chineseyear);
     font.setPointSize(15);
     this->label_15->setFont(font);
+    font.setPointSize(10);
+    this->label_17->setFont(font);
+    this->label_18->setFont(font);
+    QString yi=QString("");
+    QString ji=QString("");
+    if(chineseyilist.count() == 0 )
+       yi =QString("");
+    if(chineseyilist.count() >= 5)
+       yi = QString("").append(chineseyilist.at(0)).append("\n").append(chineseyilist.at(1)).append("\n").append(chineseyilist.at(2)).append("\n").append(chineseyilist.at(3)).append("\n").append(chineseyilist.at(4));
+    if(chineseyilist.count() == 4)
+       yi = QString("").append(chineseyilist.at(0)).append("\n").append(chineseyilist.at(1)).append("\n").append(chineseyilist.at(2)).append("\n").append(chineseyilist.at(3));
+    if (chineseyilist.count() == 3)
+       yi = QString("").append(chineseyilist.at(0)).append("\n").append(chineseyilist.at(1)).append("\n").append(chineseyilist.at(2));
+    if (chineseyilist.count() == 2)
+       yi = QString("").append(chineseyilist.at(0)).append("\n").append(chineseyilist.at(1));
+    if (chineseyilist.count() == 1)
+       yi = QString("").append(chineseyilist.at(0)).append("\n");
+    this->label_17->setText(yi);
 
+    if(chinesejilist.count() == 0 )
+       ji =QString("");
+    if(chinesejilist.count() >= 5)
+       ji = QString("").append(chinesejilist.at(0)).append("\n").append(chinesejilist.at(1)).append("\n").append(chinesejilist.at(2)).append("\n").append(chinesejilist.at(3)).append("\n").append(chinesejilist.at(4));
+    if(chinesejilist.count() == 4)
+       ji = QString("").append(chinesejilist.at(0)).append("\n").append(chinesejilist.at(1)).append("\n").append(chinesejilist.at(2)).append("\n").append(chinesejilist.at(3));
+    if (chinesejilist.count() == 3)
+       ji = QString("").append(chinesejilist.at(0)).append("\n").append(chinesejilist.at(1)).append("\n").append(chinesejilist.at(2));
+    if (chinesejilist.count() == 2)
+       ji = QString("").append(chinesejilist.at(0)).append("\n").append(chinesejilist.at(1));
+    if (chinesejilist.count() == 1)
+       ji = QString("").append(chinesejilist.at(0)).append("\n");
+    this->label_18->setText(ji);
+
+    QString cnote=mycalendat->ctcl_displaydata(day.year(),day.month(),day.day(),cnote);
+    QString haveplan=QString("今日有行程安排");
+    QString noplan=QString("今日无行程安排");
+    QStringList cnotelist=cnote.split(" ");
+    int count=cnotelist.count();
+    QString space=QString("");
+    while(count>0&&(cnotelist.at(count-1)==space))
+    {
+        count--;
+    }
+    if(cnote.isEmpty()||count==0)
+        this->label_19->setText(noplan);
+    else
+        this->label_19->setText(haveplan);
     pa.setColor(QPalette::WindowText,Qt::white);
     this->label->setPalette(pa);
     this->label_2->setPalette(pa);
@@ -111,7 +175,11 @@ ChineseCalendar::ChineseCalendar(QWidget *parent)
 
     pa.setColor(QPalette::WindowText,QColor(255,255,255));
     this->label_3->setPalette(pa);
-    this->label_9->setPalette(pa);
+    this->label_9->setPalette(pa); 
+
+    pa.setColor(QPalette::WindowText,Qt::black);
+    this->label_18->setPalette(pa);
+    this->label_19->setPalette(pa);
 
     pa.setColor(QPalette::WindowText,Qt::red);
     this->label_10->setPalette(pa);
@@ -119,192 +187,230 @@ ChineseCalendar::ChineseCalendar(QWidget *parent)
     this->label_12->setPalette(pa);
     this->label_13->setPalette(pa);
     this->label_14->setPalette(pa);
+    this->label_17->setPalette(pa);
 
     map = new QMap<QString, DateItem *>();
     DateItem *dateitem00 = new DateItem(this);
     dateitem00->show();
     map->insert(QString("1-1"), dateitem00 );
     connect(dateitem00, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
+    connect(dateitem00, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
 
     DateItem *dateitem01 = new DateItem(this);
     dateitem01->show();
     map->insert(QString("1-2"), dateitem01 );
     connect(dateitem01, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
+    connect(dateitem01, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
 
     DateItem *dateitem02 = new DateItem(this);
     dateitem02->show();
     map->insert(QString("1-3"), dateitem02 );
     connect(dateitem02, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
+    connect(dateitem02, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
 
     DateItem *dateitem03 = new DateItem(this);
     dateitem03->show();
     map->insert(QString("1-4"), dateitem03 );
     connect(dateitem03, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
+    connect(dateitem03, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
 
     DateItem *dateitem04 = new DateItem(this);
     dateitem04->show();
     map->insert(QString("1-5"), dateitem04 );
     connect(dateitem04, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
+    connect(dateitem04, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
 
     DateItem *dateitem05 = new DateItem(this);
     dateitem05->show();
     map->insert(QString("1-6"), dateitem05 );
     connect(dateitem05, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
+    connect(dateitem05, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
 
     DateItem *dateitem06 = new DateItem(this);
     dateitem06->show();
     map->insert(QString("1-7"), dateitem06 );
     connect(dateitem06, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
+    connect(dateitem06, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
 
     DateItem *dateitem10 = new DateItem(this);
     dateitem10->show();
     map->insert(QString("2-1"), dateitem10 );
     connect(dateitem10, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
+    connect(dateitem10, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
 
     DateItem *dateitem11 = new DateItem(this);
     dateitem11->show();
     map->insert(QString("2-2"), dateitem11 );
     connect(dateitem11, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
+    connect(dateitem11, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
 
     DateItem *dateitem12 = new DateItem(this);
     dateitem12->show();
     map->insert(QString("2-3"), dateitem12 );
     connect(dateitem12, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
+    connect(dateitem12, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
 
     DateItem *dateitem13 = new DateItem(this);
     dateitem13->show();
     map->insert(QString("2-4"), dateitem13 );
     connect(dateitem13, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
+    connect(dateitem13, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
 
     DateItem *dateitem14 = new DateItem(this);
     dateitem14->show();
     map->insert(QString("2-5"), dateitem14 );
     connect(dateitem14, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
+    connect(dateitem14, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
 
     DateItem *dateitem15 = new DateItem(this);
     dateitem15->show();
     map->insert(QString("2-6"), dateitem15 );
     connect(dateitem15, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
+    connect(dateitem15, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
 
     DateItem *dateitem16 = new DateItem(this);
     dateitem16->show();
     map->insert(QString("2-7"), dateitem16 );
     connect(dateitem16, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
+    connect(dateitem16, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
 
     DateItem *dateitem20 = new DateItem(this);
     dateitem20->show();
     map->insert(QString("3-1"), dateitem20 );
     connect(dateitem20, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
+    connect(dateitem20, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
 
     DateItem *dateitem21 = new DateItem(this);
     dateitem21->show();
     map->insert(QString("3-2"), dateitem21 );
     connect(dateitem21, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
+    connect(dateitem21, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
 
     DateItem *dateitem22 = new DateItem(this);
     dateitem22->show();
     map->insert(QString("3-3"), dateitem22 );
     connect(dateitem22, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
+    connect(dateitem22, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
 
     DateItem *dateitem23 = new DateItem(this);
     dateitem23->show();
     map->insert(QString("3-4"), dateitem23 );
     connect(dateitem23, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
+    connect(dateitem23, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
 
     DateItem *dateitem24 = new DateItem(this);
     dateitem24->show();
     map->insert(QString("3-5"), dateitem24 );
     connect(dateitem24, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
+    connect(dateitem24, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
 
     DateItem *dateitem25 = new DateItem(this);
     dateitem25->show();
     map->insert(QString("3-6"), dateitem25 );
     connect(dateitem25, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
+    connect(dateitem25, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
 
     DateItem *dateitem26 = new DateItem(this);
     dateitem26->show();
     map->insert(QString("3-7"), dateitem26 );
     connect(dateitem26, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
+    connect(dateitem26, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
 
     DateItem *dateitem30 = new DateItem(this);
     dateitem30->show();
     map->insert(QString("4-1"), dateitem30 );
     connect(dateitem30, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
+    connect(dateitem30, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
 
     DateItem *dateitem31 = new DateItem(this);
     dateitem31->show();
     map->insert(QString("4-2"), dateitem31 );
     connect(dateitem31, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
+    connect(dateitem31, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
 
     DateItem *dateitem32 = new DateItem(this);
     dateitem32->show();
     map->insert(QString("4-3"), dateitem32 );
     connect(dateitem32, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
+    connect(dateitem32, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
 
     DateItem *dateitem33 = new DateItem(this);
     dateitem33->show();
     map->insert(QString("4-4"), dateitem33 );
     connect(dateitem33, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
+    connect(dateitem33, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
 
     DateItem *dateitem34 = new DateItem(this);
     dateitem34->show();
     map->insert(QString("4-5"), dateitem34 );
     connect(dateitem34, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
+    connect(dateitem34, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
 
     DateItem *dateitem35 = new DateItem(this);
     dateitem35->show();
     map->insert(QString("4-6"), dateitem35 );
     connect(dateitem35, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
+    connect(dateitem35, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
 
     DateItem *dateitem36 = new DateItem(this);
     dateitem36->show();
     map->insert(QString("4-7"), dateitem36 );
     connect(dateitem36, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
+    connect(dateitem36, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
 
     DateItem *dateitem40 = new DateItem(this);
     dateitem40->show();
     map->insert(QString("5-1"), dateitem40 );
     connect(dateitem40, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
+    connect(dateitem40, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
 
     DateItem *dateitem41 = new DateItem(this);
     dateitem41->show();
     map->insert(QString("5-2"), dateitem41 );
     connect(dateitem41, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
+    connect(dateitem41, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
 
     DateItem *dateitem42 = new DateItem(this);
     dateitem42->show();
     map->insert(QString("5-3"), dateitem42 );
     connect(dateitem42, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
+    connect(dateitem42, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
 
     DateItem *dateitem43 = new DateItem(this);
     dateitem43->show();
     map->insert(QString("5-4"), dateitem43 );
     connect(dateitem43, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
+    connect(dateitem43, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
 
     DateItem *dateitem44 = new DateItem(this);
     dateitem44->show();
     map->insert(QString("5-5"), dateitem44 );
     connect(dateitem44, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
+    connect(dateitem44, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
 
     DateItem *dateitem45 = new DateItem(this);
     dateitem45->show();
     map->insert(QString("5-6"), dateitem45 );
     connect(dateitem45, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
+    connect(dateitem45, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
 
     DateItem *dateitem46 = new DateItem(this);
     dateitem46->show();
     map->insert(QString("5-7"), dateitem46 );
     connect(dateitem46, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
+    connect(dateitem46, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
 
     DateItem *dateitem50 = new DateItem(this);
     dateitem50->hide();
     map->insert(QString("6-1"), dateitem50 );
     connect(dateitem50, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
+    connect(dateitem50, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
 
     DateItem *dateitem51 = new DateItem(this);
     dateitem51->hide();
     map->insert(QString("6-2"), dateitem51 );
     connect(dateitem51, SIGNAL(clicked(QString)), this, SLOT(resetcalendardate(QString)));
+    connect(dateitem51, SIGNAL(day(QString)), this, SLOT(setclickday(QString)));
 
     DateItem *dateitem52 = new DateItem(this);
     dateitem52->hide();
@@ -341,10 +447,6 @@ ChineseCalendar::ChineseCalendar(QWidget *parent)
     painter.drawRoundedRect(this->rect(),10,10);
     setMask(objBitmap);
 
-//    Display *dis = QX11Info::display ();
-//    Atom atom_task = XInternAtom(QX11Info::display (),"_NET_WM_STATE_SKIP_TASKBAR",False);
-//    Atom atom =  XInternAtom(dis,"_NET_WM_STATE",False);
-//    XChangeProperty(dis,winId(),atom,XA_ATOM,32,PropModeAppend,(unsigned char *)&atom_task,1);
 
     this->createTray();
 }
@@ -354,6 +456,30 @@ ChineseCalendar::~ChineseCalendar()
   delete mycalendat;
 }
 
+void ChineseCalendar::setclickday(QString day)
+{
+    clickday = day.toInt();
+    int year = this->YearSelect->currentText().toInt();
+    int month = this->monthCombo->currentText().toInt();
+    int today = clickday;
+    QString dateplan = QString("%1月%2日计划安排").arg(this->monthCombo->currentText()).arg(day);
+    QString data;
+    data=mycalendat->ctcl_displaydata(year,month,today,data);
+    note->textedit->setText(data);
+    note->datelabel->setText(dateplan);
+}
+
+void ChineseCalendar::savedata(QString data)
+{
+    int year = this->YearSelect->currentText().toInt();
+    int month = this->monthCombo->currentText().toInt();
+    int day = clickday;
+    QString note = data;  
+    mycalendat->ctcl_savenote(year,month,day,data);
+
+}
+
+
 void ChineseCalendar::createTray()
 {
     this->actionShow = new QAction(tr("隐藏/显示"), this);
@@ -620,7 +746,7 @@ void ChineseCalendar::setTime()
 
 void ChineseCalendar::resetcalendardate(QString day)
 {
-    QDate date(this->YearSelect->date().year(),this->monthCombo->currentText().toInt(),day.toInt());
+    QDate date(this->YearSelect->currentText().toInt(),this->monthCombo->currentText().toInt(),day.toInt());
     clearbackground();
     QString weekday;
     if(date.toString("ddd") == "Mon")
@@ -647,18 +773,88 @@ void ChineseCalendar::resetcalendardate(QString day)
         selectmonth = "冬月";
     if (selectmonth == "十二月")
         selectmonth = "腊月";
+    struct CCalendar f = fixshengxiao(date);
     QString selectday = QString("农历 %1%2").arg(selectmonth).arg(d.cday);
-    QString selectyear = QString("%1年(%2年)").arg(d.ganzhi).arg(d.shengxiao);
+    QString selectyear = QString("%1年(%2年)").arg(f.ganzhi).arg(f.shengxiao);
     this->label_10->setText(day);
     this->label_12->setText(selecttime);
     this->label_13->setText(selectday);
     this->label_14->setText(selectyear);
+
+    QString cnote=QString("");
+    QString haveplan=QString("今日有行程安排");
+    QString noplan=QString("今日无行程安排");
+    cnote=mycalendat->ctcl_displaydata(date.year(),date.month(),date.day(),cnote);
+    QStringList cnotelist=cnote.split(" ");
+    QString space=QString("");
+    int count=cnotelist.count();
+    while(count>0&&(cnotelist.at(count-1)==space))
+    {
+        count--;
+    }
+    if(cnote.isEmpty()||count==0)
+        this->label_19->setText(noplan);
+    else
+        this->label_19->setText(haveplan);
+
+    QString yi = QString("");
+    QString ji = QString("");
+    QString selectyi = QString("%1").arg(f.yi);
+    QStringList selectyilist = selectyi.split("、");
+    if(selectyilist.count() == 0 )
+       yi =QString("");
+    if(selectyilist.count() >= 5)
+       yi = QString("").append(selectyilist.at(0)).append("\n").append(selectyilist.at(1)).append("\n").append(selectyilist.at(2)).append("\n").append(selectyilist.at(3)).append("\n").append(selectyilist.at(4));
+    if(selectyilist.count() == 4)
+       yi = QString("").append(selectyilist.at(0)).append("\n").append(selectyilist.at(1)).append("\n").append(selectyilist.at(2)).append("\n").append(selectyilist.at(3));
+    if (selectyilist.count() == 3)
+       yi = QString("").append(selectyilist.at(0)).append("\n").append(selectyilist.at(1)).append("\n").append(selectyilist.at(2));
+    if (selectyilist.count() == 2)
+       yi = QString("").append(selectyilist.at(0)).append("\n").append(selectyilist.at(1));
+    if (selectyilist.count() == 1)
+       yi = QString("").append(selectyilist.at(0)).append("\n");
+
+    QString selectji = QString("%2").arg(f.ji);
+    QStringList selectjilist = selectji.split("、");
+    if(selectjilist.count() == 0 )
+       ji =QString("");
+    if(selectjilist.count() >= 5)
+       ji = QString("").append(selectjilist.at(0)).append("\n").append(selectjilist.at(1)).append("\n").append(selectjilist.at(2)).append("\n").append(selectjilist.at(3)).append("\n").append(selectjilist.at(4));
+    if(selectjilist.count() == 4)
+       ji = QString("").append(selectjilist.at(0)).append("\n").append(selectjilist.at(1)).append("\n").append(selectjilist.at(2)).append("\n").append(selectjilist.at(3));
+    if (selectjilist.count() == 3)
+       ji = QString("").append(selectjilist.at(0)).append("\n").append(selectjilist.at(1)).append("\n").append(selectjilist.at(2));
+    if (selectjilist.count() == 2)
+       ji = QString("").append(selectjilist.at(0)).append("\n").append(selectjilist.at(1));
+    if (selectjilist.count() == 1)
+       ji = QString("").append(selectjilist.at(0)).append("\n");
+    this->label_17->setText(yi);
+    this->label_18->setText(ji);
+}
+
+CCalendar ChineseCalendar::fixshengxiao(QDate date)
+{
+    QDate fixdate = date.addDays(1);
+    struct CCalendar fix;
+    mycalendat->ctcl_solar_to_lunar(fixdate.year(),fixdate.month(),fixdate.day(),&fix);
+    if (fix.sterm == "立春")
+    {
+        fixdate = fixdate.addDays(-2);
+        mycalendat->ctcl_solar_to_lunar(fixdate.year(),fixdate.month(),fixdate.day(),&fix);
+        return fix;
+    }
+    else
+    {
+        fixdate = fixdate.addDays(-1);
+        mycalendat->ctcl_solar_to_lunar(fixdate.year(),fixdate.month(),fixdate.day(),&fix);
+        return fix;
+    }
 }
 
 void ChineseCalendar::backtoday()
 {
     QDate today = QDate::currentDate();
-    YearSelect->setDate(today);
+    YearSelect->setCurrentIndex(today.year() - 1900);
     monthCombo->setCurrentIndex(today.month() - 1);
     setCalendar();
 
@@ -912,22 +1108,23 @@ void ChineseCalendar::setMonth(int month)
     setCalendar();
 }
 
-void ChineseCalendar::setYear(QDate date)
+void ChineseCalendar::setYear(int year)
 {
-    selectedDate = QDate(date.year(), selectedDate.month(), selectedDate.day());
+    selectedDate = QDate(year+1900, selectedDate.month(), selectedDate.day());
     setCalendar();
 }
 
 void ChineseCalendar::on_TbpreviousYear_clicked()
 {
-	YearSelect->setDate(selectedDate.addYears(-1));
+    if(YearSelect->currentIndex() != 0)
+        YearSelect->setCurrentIndex(YearSelect->currentIndex()-1);
 }
 
 void ChineseCalendar::on_TbpreviousMonth_clicked()
 {
-    if (monthCombo->currentIndex() == 0)
+    if (monthCombo->currentIndex() == 0 && YearSelect->currentIndex() != 0)
     {
-        YearSelect->setDate(selectedDate.addYears(-1));
+        YearSelect->setCurrentIndex(YearSelect->currentIndex()-1);
         monthCombo->setCurrentIndex(11);
     }
     else
@@ -936,9 +1133,9 @@ void ChineseCalendar::on_TbpreviousMonth_clicked()
 
 void ChineseCalendar::on_TbnextMonth_clicked()
 {
-    if (monthCombo->currentIndex() == 11)
+    if (monthCombo->currentIndex() == 11 && YearSelect->currentIndex() != 150)
     {
-        YearSelect->setDate(selectedDate.addYears(1));
+        YearSelect->setCurrentIndex(YearSelect->currentIndex()+1);
         monthCombo->setCurrentIndex(0);
     }
     else
@@ -947,7 +1144,8 @@ void ChineseCalendar::on_TbnextMonth_clicked()
 
 void ChineseCalendar::on_TbnextYear_clicked()
 {
-	YearSelect->setDate(selectedDate.addYears(1));
+    if(YearSelect->currentIndex() != 150)
+        YearSelect->setCurrentIndex(YearSelect->currentIndex()+1);
 }
 
 void ChineseCalendar::showOrHide()
